@@ -21,7 +21,6 @@
  *
  * ============================================================ */
 
-#include "slideshowconfig.h"
 #include "slideshowconfig.moc"
 
 // Qt includes
@@ -73,7 +72,7 @@ public:
     KConfig*                  config;
 };
 
-SlideShowConfig::SlideShowConfig (QWidget *parent, SharedContainer* sharedData)
+SlideShowConfig::SlideShowConfig (QWidget* parent, SharedContainer* sharedData)
                : KPageDialog(parent), d(new SlideShowConfigPrivate)
 {
     setObjectName("Advanced Slideshow Settings");
@@ -118,7 +117,7 @@ SlideShowConfig::SlideShowConfig (QWidget *parent, SharedContainer* sharedData)
                                             KAboutData::License_GPL,
                                             ki18n("A Kipi plugin for image slideshows"),
                                             ki18n("(c) 2003-2004, Renchi Raju\n"
-                                                  "(c) 2006-2008, Valerio Fuoglio"));
+                                                  "(c) 2006-2009, Valerio Fuoglio"));
 
     d->about->addAuthor(ki18n( "Renchi Raju" ), ki18n("Author"),
                         "renchi dot raju at gmail dot com");
@@ -129,7 +128,7 @@ SlideShowConfig::SlideShowConfig (QWidget *parent, SharedContainer* sharedData)
                this, SLOT(slotHelp()));
 
     KHelpMenu* helpMenu = new KHelpMenu(this, d->about, false);
-    QAction *handbook   = new QAction(i18n("Handbook"), this);
+    QAction* handbook   = new QAction(i18n("Handbook"), this);
 
     connect(handbook, SIGNAL(triggered(bool)),
             this, SLOT(slotHelp()));
@@ -189,7 +188,8 @@ void SlideShowConfig::readSettings()
 
     d->sharedData->commentsFontColor   = grp.readEntry("Comments Font Color", 0xffffff);
     d->sharedData->commentsBgColor     = grp.readEntry("Comments Bg Color", 0x000000);
-    d->sharedData->transparentBg       = grp.readEntry("Transparent Bg", true);
+    d->sharedData->commentsDrawOutline = grp.readEntry("Comments Text Outline", true);
+    d->sharedData->bgOpacity           = grp.readEntry("Background Opacity", 10);
 
     d->sharedData->commentsLinesLength = grp.readEntry("Comments Lines Length", 72);
 
@@ -266,7 +266,8 @@ void SlideShowConfig::saveSettings()
     grp.writeEntry("Comments Font FixedPitch", commentsFont->fixedPitch());
     grp.writeEntry("Comments Font Color",      d->sharedData->commentsFontColor);
     grp.writeEntry("Comments Bg Color",        d->sharedData->commentsBgColor);
-    grp.writeEntry("Transparent Bg",           d->sharedData->transparentBg);
+    grp.writeEntry("Comments Text Outline",    d->sharedData->commentsDrawOutline);
+    grp.writeEntry("Background Opacity",       d->sharedData->bgOpacity);
     grp.writeEntry("Comments Lines Length",    d->sharedData->commentsLinesLength);
     grp.writeEntry("Effect Name (OpenGL)",     d->sharedData->effectNameGL);
     grp.writeEntry("Effect Name",              d->sharedData->effectName);
