@@ -25,11 +25,11 @@
 #ifndef PLUGIN_REMOVEREDEYES_H
 #define PLUGIN_REMOVEREDEYES_H
 
-// Qt includes.
+// Qt includes
 
 #include <QVariant>
 
-// LibKIPI includes.
+// LibKIPI includes
 
 #include <libkipi/plugin.h>
 
@@ -41,13 +41,13 @@ class Plugin_RemoveRedEyes: public KIPI::Plugin
 
 public:
 
-    Plugin_RemoveRedEyes(QObject *parent, const QVariantList &args);
+    Plugin_RemoveRedEyes(QObject* parent, const QVariantList& args);
     ~Plugin_RemoveRedEyes();
 
     KIPI::Category category(KAction* action) const;
     void setup(QWidget* widget);
 
-private slots:
+private Q_SLOTS:
 
     void activate();
 
