@@ -20,7 +20,6 @@
  *
  * ============================================================ */
 
-#include "plugin_sendimages.h"
 #include "plugin_sendimages.moc"
 
 // KDE includes
@@ -120,7 +119,7 @@ void Plugin_SendImages::slotActivate()
     if ( !images.isValid() || images.images().isEmpty() )
         return;
 
-    if (d->dialog) delete d->dialog;
+    delete d->dialog;
 
     d->dialog = new SendImagesDialog(kapp->activeWindow(), interface, images.images());
     d->dialog->show();
