@@ -46,7 +46,7 @@
 // KDE includes
 
 #include <KCodecs>
-#include <KDebug>
+#include <kdebug.h>
 #include <KUrl>
 #include <KIO/Job>
 #include <KIO/JobUiDelegate>
@@ -100,12 +100,12 @@ SwUser SwConnector::getUser() const
     return m_user;
 }
 
-void SwConnector::setUser(SwUser user)
+void SwConnector::setUser(const SwUser& user)
 {
     m_user = user;
 }
 
-bool SwConnector::isLoggedIn()
+bool SwConnector::isLoggedIn() const
 {
     return m_loggedIn;
 }
